@@ -1,12 +1,12 @@
-# Path: invoke\api\app\__init__.py
+# Path: api\app\__init__.py
 from .app_api import AppApi
-from .schema import AppVersion, AppDeps, AppConfig, LogLevel, CacheStatus
+from .schema import AppVersion, AppDeps, UpscalingMethod, AppConfig, CacheStatus
 
 __all__ = [
     "AppApi",
     "AppVersion",
     "AppDeps",
+    "UpscalingMethod",
     "AppConfig",
-    "LogLevel",
     "CacheStatus",
 ]
